# This file was auto-generated by Fern from our API Definition.

from ....core.api_error import ApiError
from ..types.updates_disabled_due_to_external_system_integration_error_message import (
    UpdatesDisabledDueToExternalSystemIntegrationErrorMessage,
)


class UpdatesDisabledDueToExternalSystemIntegrationError(ApiError):
    def __init__(self, body: UpdatesDisabledDueToExternalSystemIntegrationErrorMessage):
        super().__init__(status_code=422, body=body)
