# This file was auto-generated by Fern from our API Definition.

from ......core.api_error import ApiError
from ..types.contract_is_linked_to_fee_schedule_error import ContractIsLinkedToFeeScheduleError


class ContractIsLinkedToFeeScheduleHttpError(ApiError):
    def __init__(self, body: ContractIsLinkedToFeeScheduleError):
        super().__init__(status_code=422, body=body)
