# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ServiceLineUnits(str, enum.Enum):
    MJ = "MJ"
    UN = "UN"

    def visit(self, mj: typing.Callable[[], T_Result], un: typing.Callable[[], T_Result]) -> T_Result:
        if self is ServiceLineUnits.MJ:
            return mj()
        if self is ServiceLineUnits.UN:
            return un()
