# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class EmrPayerCrosswalk(str, enum.Enum):
    HEALTHIE = "HEALTHIE"
    CANVAS = "CANVAS"

    def visit(self, healthie: typing.Callable[[], T_Result], canvas: typing.Callable[[], T_Result]) -> T_Result:
        if self is EmrPayerCrosswalk.HEALTHIE:
            return healthie()
        if self is EmrPayerCrosswalk.CANVAS:
            return canvas()
