# This file was auto-generated by Fern from our API Definition.

from ......core.api_error import ApiError
from ..types.task_updated_to_deprecated_status_error_type import TaskUpdatedToDeprecatedStatusErrorType


class TaskUpdatedToDeprecatedStatusError(ApiError):
    def __init__(self, body: TaskUpdatedToDeprecatedStatusErrorType):
        super().__init__(status_code=422, body=body)
