# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class LabCodeType(str, enum.Enum):
    QUEST = "quest"
    LABCORP = "labcorp"

    def visit(self, quest: typing.Callable[[], T_Result], labcorp: typing.Callable[[], T_Result]) -> T_Result:
        if self is LabCodeType.QUEST:
            return quest()
        if self is LabCodeType.LABCORP:
            return labcorp()
