# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class InsurancePaymentSortField(str, enum.Enum):
    AMOUNT_CENTS = "amount_cents"
    PAYMENT_TIMESTAMP = "payment_timestamp"
    PAYMENT_NOTE = "payment_note"

    def visit(
        self,
        amount_cents: typing.Callable[[], T_Result],
        payment_timestamp: typing.Callable[[], T_Result],
        payment_note: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is InsurancePaymentSortField.AMOUNT_CENTS:
            return amount_cents()
        if self is InsurancePaymentSortField.PAYMENT_TIMESTAMP:
            return payment_timestamp()
        if self is InsurancePaymentSortField.PAYMENT_NOTE:
            return payment_note()
