# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class AddressType(str, enum.Enum):
    DEFAULT = "DEFAULT"

    def visit(self, default: typing.Callable[[], T_Result]) -> T_Result:
        if self is AddressType.DEFAULT:
            return default()
