# This file was auto-generated by Fern from our API Definition.

from ......core.api_error import ApiError
from ..types.encounter_has_existing_guarantor_error_type import EncounterHasExistingGuarantorErrorType


class EncounterHasExistingGuarantorError(ApiError):
    def __init__(self, body: EncounterHasExistingGuarantorErrorType):
        super().__init__(status_code=409, body=body)
