# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ....core.datetime_utils import serialize_datetime
from ....core.pydantic_utilities import deep_union_pydantic_dicts
from ...commons.types.date import Date
from ...commons.types.invoice_id import InvoiceId
from ...commons.types.organization_id import OrganizationId
from ...commons.types.patient_external_id import PatientExternalId
from .invoice_item import InvoiceItem
from .invoice_status import InvoiceStatus


class Invoice(pydantic.BaseModel):
    id: InvoiceId
    created_at: dt.datetime
    updated_at: dt.datetime
    organzation_id: OrganizationId
    source_id: str
    source_customer_id: str
    patient_external_id: PatientExternalId
    note: typing.Optional[str] = None
    due_date: Date
    status: InvoiceStatus
    url: typing.Optional[str] = None
    customer_invoice_url: typing.Optional[str] = None
    items: typing.List[InvoiceItem]

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults_exclude_unset: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        kwargs_with_defaults_exclude_none: typing.Any = {"by_alias": True, "exclude_none": True, **kwargs}

        return deep_union_pydantic_dicts(
            super().dict(**kwargs_with_defaults_exclude_unset), super().dict(**kwargs_with_defaults_exclude_none)
        )

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic.Extra.forbid
        json_encoders = {dt.datetime: serialize_datetime}
