# This file was auto-generated by Fern from our API Definition.

import typing

from ......core.api_error import ApiError
from ..types.rate_upload_with_possible_errors import RateUploadWithPossibleErrors


class FeeScheduleValidationHttpError(ApiError):
    def __init__(self, body: typing.List[RateUploadWithPossibleErrors]):
        super().__init__(status_code=422, body=body)
