# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ServiceFacilityStatus(str, enum.Enum):
    """
    Examples
    --------
    from candid.resources.organization_service_facilities.v_2 import (
        ServiceFacilityStatus,
    )

    ServiceFacilityStatus.ACTIVE
    """

    ACTIVE = "active"
    """
    The location is operational.
    """

    INACTIVE = "inactive"
    """
    The location is no longer used.
    """

    SUSPENDED = "suspended"
    """
    TThe location is temporarily closed.
    """

    def visit(
        self,
        active: typing.Callable[[], T_Result],
        inactive: typing.Callable[[], T_Result],
        suspended: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is ServiceFacilityStatus.ACTIVE:
            return active()
        if self is ServiceFacilityStatus.INACTIVE:
            return inactive()
        if self is ServiceFacilityStatus.SUSPENDED:
            return suspended()
